==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/MigrationService.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin

import com.pulumi.azurenative.datamigration.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.datamigration.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [MigrationService].
 */
@PulumiTagMarker
public class MigrationServiceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: MigrationServiceArgs = MigrationServiceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend MigrationServiceArgsBuilder.() -> Unit) {
        val builder = MigrationServiceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): MigrationService {
        val builtJavaResource =
            com.pulumi.azurenative.datamigration.MigrationService(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return MigrationService(builtJavaResource)
    }
}

/**
 * A Migration Service.
 * Azure REST API version: 2023-07-15-preview.
 * ## Example Usage
 * ### Create or Update Migration Service with maximum parameters.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var migrationService = new AzureNative.DataMigration.MigrationService("migrationService", new()
 *     {
 *         Location = "northeurope",
 *         MigrationServiceName = "testagent",
 *         ResourceGroupName = "testrg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/datamigration/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := datamigration.NewMigrationService(ctx, "migrationService", &datamigration.MigrationServiceArgs{
 * 			Location:             pulumi.String("northeurope"),
 * 			MigrationServiceName: pulumi.String("testagent"),
 * 			ResourceGroupName:    pulumi.String("testrg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.datamigration.MigrationService;
 * import com.pulumi.azurenative.datamigration.MigrationServiceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var migrationService = new MigrationService("migrationService", MigrationServiceArgs.builder()
 *             .location("northeurope")
 *             .migrationServiceName("testagent")
 *             .resourceGroupName("testrg")
 *             .build());
 *     }
 * }
 * ```
 * ### Create or Update Migration Service with minimum parameters.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var migrationService = new AzureNative.DataMigration.MigrationService("migrationService", new()
 *     {
 *         Location = "northeurope",
 *         MigrationServiceName = "testagent",
 *         ResourceGroupName = "testrg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/datamigration/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := datamigration.NewMigrationService(ctx, "migrationService", &datamigration.MigrationServiceArgs{
 * 			Location:             pulumi.String("northeurope"),
 * 			MigrationServiceName: pulumi.String("testagent"),
 * 			ResourceGroupName:    pulumi.String("testrg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.datamigration.MigrationService;
 * import com.pulumi.azurenative.datamigration.MigrationServiceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var migrationService = new MigrationService("migrationService", MigrationServiceArgs.builder()
 *             .location("northeurope")
 *             .migrationServiceName("testagent")
 *             .resourceGroupName("testrg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:datamigration:MigrationService testagent /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DataMigration/migrationServices/{migrationServiceName}
 * ```
 */
public class MigrationService internal constructor(
    override val javaResource: com.pulumi.azurenative.datamigration.MigrationService,
) : KotlinCustomResource(javaResource, MigrationServiceMapper) {
    /**
     * Current state of the Integration runtime.
     */
    public val integrationRuntimeState: Output<String>
        get() = javaResource.integrationRuntimeState().applyValue({ args0 -> args0 })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Provisioning state to track the async operation status.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object MigrationServiceMapper : ResourceMapper<MigrationService> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.datamigration.MigrationService::class == javaResource::class

    override fun map(javaResource: Resource): MigrationService = MigrationService(
        javaResource as
            com.pulumi.azurenative.datamigration.MigrationService,
    )
}

/**
 * @see [MigrationService].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [MigrationService].
 */
public suspend fun migrationService(
    name: String,
    block: suspend MigrationServiceResourceBuilder.() -> Unit,
): MigrationService {
    val builder = MigrationServiceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [MigrationService].
 * @param name The _unique_ name of the resulting resource.
 */
public fun migrationService(name: String): MigrationService {
    val builder = MigrationServiceResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/MigrationService.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin

import com.pulumi.azurenative.datamigration.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.datamigration.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [MigrationService].
 */
@PulumiTagMarker
public class MigrationServiceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: MigrationServiceArgs = MigrationServiceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend MigrationServiceArgsBuilder.() -> Unit) {
        val builder = MigrationServiceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): MigrationService {
        val builtJavaResource =
            com.pulumi.azurenative.datamigration.MigrationService(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return MigrationService(builtJavaResource)
    }
}

/**
 * A Migration Service.
 * Azure REST API version: 2023-07-15-preview.
 * ## Example Usage
 * ### Create or Update Migration Service with maximum parameters.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var migrationService = new AzureNative.DataMigration.MigrationService("migrationService", new()
 *     {
 *         Location = "northeurope",
 *         MigrationServiceName = "testagent",
 *         ResourceGroupName = "testrg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/datamigration/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := datamigration.NewMigrationService(ctx, "migrationService", &datamigration.MigrationServiceArgs{
 * 			Location:             pulumi.String("northeurope"),
 * 			MigrationServiceName: pulumi.String("testagent"),
 * 			ResourceGroupName:    pulumi.String("testrg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.datamigration.MigrationService;
 * import com.pulumi.azurenative.datamigration.MigrationServiceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var migrationService = new MigrationService("migrationService", MigrationServiceArgs.builder()
 *             .location("northeurope")
 *             .migrationServiceName("testagent")
 *             .resourceGroupName("testrg")
 *             .build());
 *     }
 * }
 * ```
 * ### Create or Update Migration Service with minimum parameters.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var migrationService = new AzureNative.DataMigration.MigrationService("migrationService", new()
 *     {
 *         Location = "northeurope",
 *         MigrationServiceName = "testagent",
 *         ResourceGroupName = "testrg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/datamigration/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := datamigration.NewMigrationService(ctx, "migrationService", &datamigration.MigrationServiceArgs{
 * 			Location:             pulumi.String("northeurope"),
 * 			MigrationServiceName: pulumi.String("testagent"),
 * 			ResourceGroupName:    pulumi.String("testrg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.datamigration.MigrationService;
 * import com.pulumi.azurenative.datamigration.MigrationServiceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var migrationService = new MigrationService("migrationService", MigrationServiceArgs.builder()
 *             .location("northeurope")
 *             .migrationServiceName("testagent")
 *             .resourceGroupName("testrg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:datamigration:MigrationService testagent /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DataMigration/migrationServices/{migrationServiceName}
 * ```
 */
public class MigrationService internal constructor(
    override val javaResource: com.pulumi.azurenative.datamigration.MigrationService,
) : KotlinCustomResource(javaResource, MigrationServiceMapper) {
    /**
     * Current state of the Integration runtime.
     */
    public val integrationRuntimeState: Output<String>
        get() = javaResource.integrationRuntimeState().applyValue({ args0 -> args0 })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Provisioning state to track the async operation status.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object MigrationServiceMapper : ResourceMapper<MigrationService> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.datamigration.MigrationService::class == javaResource::class

    override fun map(javaResource: Resource): MigrationService = MigrationService(
        javaResource as
            com.pulumi.azurenative.datamigration.MigrationService,
    )
}

/**
 * @see [MigrationService].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [MigrationService].
 */
public suspend fun migrationService(
    name: String,
    block: suspend MigrationServiceResourceBuilder.() -> Unit,
): MigrationService {
    val builder = MigrationServiceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [MigrationService].
 * @param name The _unique_ name of the resulting resource.
 */
public fun migrationService(name: String): MigrationService {
    val builder = MigrationServiceResourceBuilder()
    builder.name(name)
    return builder.build()
}
